@@ -11,6 +11,7 @@ import logging
 from cakework import exceptions
 from urllib3.exceptions import NewConnectionError
 import os
+from dotenv import load_dotenv
 
 # TODO: need to re-enable TLS for the handlers in the fly.toml file. Try these settings: https://community.fly.io/t/urgent-grpc-server-unreachable-via-grpcurl/2694/12 for alpn
 # TODO figure out how to configure the settings for fly.toml for grpc!
@@ -20,15 +21,16 @@ logging.basicConfig(level=logging.INFO)
 
 class Client:
     def __init__(self, project, client_token, local=False): # TODO: infer user id // TODO revert local back to False
-
+        load_dotenv()
         # TODO get rid of "shared"
         self.project = project.lower().replace('_', '-')
         # make a call to the frontend to get the user_id using the client token
         if local:
             self.frontend_url = "http://localhost:8080"
         else:
-            self.frontend_url = "https://cakework-frontend.fly.dev"
+            self.frontend_url = os.getenv("FRONTEND_URL")
 
+        print("Set frontend url to: " + self.frontend_url)
         response = None
         self.headers = None
         try:
@@ -44,7 +46,7 @@ class Client:
             # TODO: handle error for if can't get a user from the client token. technically
             # we should be getting a JWT token instead first
             response.raise_for_status() # TODO delete this?
-            # TODO: handle http error, or request id not foundain. error
+            # TODO: handle http error, or request id not found error
         except requests.exceptions.HTTPError as err:
             raise exceptions.CakeworkError("Http error while connecting to Cakework frontend") from err
         except requests.exceptions.Timeout as err:
@@ -131,10 +133,35 @@ class Client:
             raise exceptions.CakeworkError("Internal server exception") 
        
     def __getattr__(self, name):
-        def method(*args):
+        def method(*args, compute={}):            
             sanitized_name = name.lower()
-            sanitized_name = name.replace('_', '-')          
-            response = requests.post(f"{self.frontend_url}/client/submit-task", json={"userId": self.user_id, "app": self.project, "task": sanitized_name, "parameters": json.dumps(args)}, headers=self.headers)
+            sanitized_name = name.replace('_', '-')
+
+            parameters = json.dumps(args)
+            request = {
+                "userId": self.user_id,
+                "app": self.project,
+                "task": sanitized_name,
+                "parameters": parameters
+            }
+
+            cpu = compute.get("cpu")
+            if cpu is not None:
+                if cpu < 1 or cpu > 8:
+                    raise exceptions.CakeworkError("Number of cpus must be between 1 and 8")
+                else:
+                    request["cpu"] = cpu
+                    
+            memory = compute.get("memory")
+            if memory is not None:
+                if memory < 256 or memory > 16384:
+                    raise exceptions.CakeworkError("Amount of memory must be between 256 and 16384 mb")
+                else:
+                    request["memory"] = memory
+        
+            # print(request) # TODO delete
+  
+            response = requests.post(f"{self.frontend_url}/client/submit-task", json=request, headers=self.headers)
             response_json = response.json()
             request_id = response_json["requestId"] # this may be null?
             return request_id
